@@ -4,9 +4,6 @@ import re
 import sys
 import subprocess
 
-from space.util import get_username
-from space.util import get_password
-
 if sys.version_info >= (3, 0):  # pragma: no cover
     import urllib.request as urllib
 if sys.version_info <= (2, 8):  # pragma: no cover
@@ -82,64 +79,88 @@ def copy(sw, args):
     arg = parser.parse_args(args)
 
     if arg.pid and not arg.nvr:
-        result = sw.call(
-            'channel.software.addPackages',
+        result = _add_packages_to_channel(
+            sw,
             arg.channel,
-            [int(arg.pid)]
+            int(arg.pid)
         )
+
         if result:
             print(
                 ("Copied package id: [ {0} ] " +
                  " INTO [ {0} ] successfully!").format(arg.channel)
             )
-
             return result
 
     # Handle the search and move if nvr
     elif arg.nvr and not arg.pid:
-        
-        # return tuple for lucene search
-        pkg = _lookup_package(arg.nvr)
 
-        # need try/except to catch failed match
-        try:
-            pkg_search = sw.call(
-                'packages.search.advanced',
-                "name:\"%s\" AND version:\"%s\" AND release:\"%s\"" % (
-                    pkg[0], pkg[1], pkg[2])
-                )
-            if pkg_search == []:
-                print("Returned empty list.")
-                return False
-        except TypeError as e:
-            print("Exception caught: %s" % e.message)
+        # return tuple for lucene search
+        pkg = _parse_nvr(arg.nvr)
+
+        if not pkg:
             return False
 
-        result = sw.call(
-            'channel.software.addPackages',
-            arg.channel,
-            [pkg_search[0]['id']])
+        # perform search, will return false if empty result
+        pkg_search = _search_package_advanced(sw, pkg)
 
-        if result == 1:
-            print(
-                ("Copied package id: [ {0} ] ( {1} ) INTO [ {2} ] " +
-                "successfully!").format(
-                pkg_search[0]['id'], arg.nvr, arg.channel)
+        if pkg_search:
+            # add package to channel
+            result = _add_packages_to_channel(
+                sw,
+                arg.channel,
+                pkg_search[0]['id']
             )
-            return True
+
+            if result == 1:
+                print((
+                    "Copied package: [ {0} ] ( {1} ) " +
+                    "INTO [ {2} ] successfully!").format(
+                        pkg_search[0]['id'], arg.nvr, arg.channel
+                    )
+                )
+                return True
 
     else:
         print("Need to pass either Package ID or NVR.")
         return False
 
     return False
-    
 
 
-def _lookup_package(nvr):
-    match_obj = re.search('^([a-zA-Z0-9-_]*)-([0-9.]*)-([a-zA-Z0-9-_:.]*)', nvr)
+def _parse_nvr(nvr):
+    match_obj = re.search(
+        '^([a-zA-Z0-9-_]*)-([0-9.]*)-([a-zA-Z0-9-_:.]*)',
+        nvr
+    )
     try:
         return (match_obj.group(1), match_obj.group(2), match_obj.group(3))
     except AttributeError:
         print("Could not parse Name-Version-Relase")
-        return False
\ No newline at end of file
+        return False
+
+
+def _search_package_advanced(sw, nvr_list):
+    try:
+        pkg_search = sw.call(
+            'packages.search.advanced',
+            "name:\"%s\" AND version:\"%s\" AND release:\"%s\"" % (
+                nvr_list[0], nvr_list[1], nvr_list[2])
+        )
+        if pkg_search == []:
+            print("Returned empty list.")
+            return False
+    except TypeError as e:
+        print("Exception caught: %s" % e)
+        return False
+
+    return pkg_search
+
+
+def _add_packages_to_channel(sw, channel, pkg):
+    result = sw.call(
+        'channel.software.addPackages',
+        channel,
+        [pkg]
+    )
+    return True
